diff dwtest.c @ 2831:adb0e4ce9347

iOS: Fix multi-line container display, had to stop using buttons for images. Still need to connect the signal handlers to the column buttons. Switch to using Multi-line container mode in the test program on mobile.
author bsmith@81767d24-ef19-dc11-ae90-00e081727c95
date Sat, 10 Sep 2022 22:03:47 +0000
parents 455d539ac555
children 444031116159
line wrap: on
line diff
--- a/dwtest.c	Fri Sep 09 08:42:22 2022 +0000
+++ b/dwtest.c	Sat Sep 10 22:03:47 2022 +0000
@@ -2193,8 +2193,8 @@
         dw_feature_set(DW_FEATURE_DARK_MODE, DW_DARK_MODE_FULL);
 
 #ifdef DW_MOBILE
-    /* Enable extra container display on Mobile platforms */
-    dw_feature_set(DW_FEATURE_CONTAINER_MODE, DW_CONTAINER_MODE_EXTRA);
+    /* Enable multi-line container display on Mobile platforms */
+    dw_feature_set(DW_FEATURE_CONTAINER_MODE, DW_CONTAINER_MODE_MULTI);
 #endif
 
     /* Initialize the Dynamic Windows engine */